@@ -3,7 +3,7 @@ from ..utils.sort import Sort
 from .registry import Registry
 
 class ComponentRegistry(DependencyRegistry):
-    _components: list[Registry] = []
+    _components: list = []
 
     def add(self, key_class, value_class=None):
         if value_class is None:
@@ -14,5 +14,5 @@ class ComponentRegistry(DependencyRegistry):
         list_dependencies = self.get_dependencies(value_class)
         self._components.append(Registry(key, list_dependencies, value_class))
 
-    def get_components(self) -> list[Registry]:
+    def get_components(self) -> list:
         return self._components
\ No newline at end of file
