@@ -30,7 +30,7 @@ class BaseController:
 
         return self.instance
 
-    def search_methods(self, type) -> list[str]:
+    def search_methods(self, type) -> list:
         response = []
         methods = dir(self.klass)
         for method_name in methods:
